@@ -1,6 +1,6 @@
 /*
     GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    Copyright (C) 2001-2004 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #ifndef __GNOME_CMD_FILE_PROPS_DIALOG_H__
 #define __GNOME_CMD_FILE_PROPS_DIALOG_H__
 
-#include "gnome-cmd-file-types.h"
+#include "gnome-cmd-file.h"
 
 
 GtkWidget*
