@@ -1,6 +1,6 @@
 /*
     GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    Copyright (C) 2001-2004 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,10 +19,7 @@
 #ifndef __GNOME_CMD_RENAME_DIALOG_H__
 #define __GNOME_CMD_RENAME_DIALOG_H__
 
-#include "gnome-cmd-file-types.h"
-#include "gnome-cmd-string-dialog.h"
-
-BEGIN_GNOME_DECLS
+#include "gnome-cmd-file.h"
 
 #define GNOME_CMD_RENAME_DIALOG(obj) \
 	GTK_CHECK_CAST (obj, gnome_cmd_rename_dialog_get_type (), GnomeCmdRenameDialog)
