@@ -1,6 +1,6 @@
 /*
     GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    Copyright (C) 2001-2004 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -267,24 +267,6 @@ update_xfer_gui_func (XferData *data)
 	}
 
 	if (data->done) {
-		/* Remove files from the source file-list when a move
-		   operation has finished */
-		if (data->xferOptions & GNOME_VFS_XFER_REMOVESOURCE) {
-			if (data->src_fl && data->src_files)
-				gnome_cmd_file_list_remove_files (
-					data->src_fl, data->src_files);
-		}
-		
-		/* Only update the files if needed */
-		if (data->to_dir) {
-			gnome_cmd_dir_list_files (data->to_dir, FALSE);
-		}
-
-		if (data->to_dir) {
-			gnome_cmd_dir_unref (data->to_dir);
-			data->to_dir = NULL;
-		}
-
 		if (data->win) {
 			gtk_widget_destroy (GTK_WIDGET (data->win));
 			data->win = NULL;
