@@ -1,6 +1,6 @@
 /*
   GNOME Commander - A GNOME based file manager 
-  Copyright (C) 2001-2003 Marcus Bjurman
+  Copyright (C) 2001-2004 Marcus Bjurman
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,10 +38,12 @@ typedef struct
 	gpointer *args;
 	
 } TmpDlData;
+
 #ifdef HAVE_LOCALE_H
 extern struct lconv *locale_information;
 #endif
 
+#define FIX_PW_HACK
 #define STRINGS_TO_URIS_CHUNK 1024
 
 static GdkCursor *cursor_busy = NULL;
@@ -866,6 +868,7 @@ strings_to_uris (gchar *data)
 
 		fn = g_strdup (filenames[i]);
 		uri = gnome_vfs_uri_new (fn);
+		fix_uri (uri);
 		if (uri)
 			uri_list = g_list_append (uri_list, uri);
 		g_free (fn);
@@ -1385,3 +1388,33 @@ edit_mimetypes (const gchar *mime_type, gboolean blocking)
 		run_command (cmd, FALSE);
 	g_free (cmd);
 }
+
+
+void fix_uri (GnomeVFSURI *uri)
+{
+#ifdef FIX_PW_HACK
+	gchar *p, *t;
+	const gchar *hn, *pw;
+		
+	hn = gnome_vfs_uri_get_host_name (uri);
+	if (!hn) return;
+	
+	pw = gnome_vfs_uri_get_password (uri);
+
+	t = g_strdup (hn);
+	p = g_strrstr (t, "@");
+	if (p && p[1] != '\0') {
+		gchar *hn2;
+		gchar *pw2;
+		*p = '\0';
+		hn2 = g_strdup (p+1);
+		pw2 = g_strdup_printf ("%s@%s", pw, t);
+		gnome_vfs_uri_set_host_name (uri, hn2);
+		gnome_vfs_uri_set_password (uri, pw2);
+		g_free (hn2);
+		g_free (pw2);
+	}
+	g_free (t);
+#endif
+}
+
